@@ -10,9 +10,9 @@ from sk_transformers.utils import check_ready_to_transform
 
 
 class MathExpressionTransformer(BaseTransformer):
-    """
-    Applies an function/operation to a column and a given value or column.
-    The operation can be a function from NumPy's [mathematical functions](https://numpy.org/doc/stable/reference/routines.math.html#mathematical-functions)  or [`operator`](https://docs.python.org/3/library/operator.html#module-operator) package.
+    """Applies an function/operation to a column and a given value or column.
+    The operation can be a function from NumPy's mathematical functions or
+    operator package.
 
     **Warning!** Some functions/operators may not work as expected. Especially not all NumPy methods are supported. For example:
     various NumPy methods return values which are not fitting the size of the source column.
@@ -20,7 +20,7 @@ class MathExpressionTransformer(BaseTransformer):
     Example:
     ```python
     import pandas as pd
-    from sk_transformers.number_transformer import MathExpressionTransformer
+    from sk_transformers import MathExpressionTransformer
 
     X = pd.DataFrame({"foo": [1, 2, 3], "bar": [4, 5, 6]})
     transformer = MathExpressionTransformer([("foo", "np.sum", "bar", {"axis": 0})])
@@ -73,8 +73,7 @@ class MathExpressionTransformer(BaseTransformer):
         return is_np_op, op
 
     def __abbreviate_numpy_in_operation(self, operation: str) -> str:
-        """
-        Replaces `numpy` at the start of a string with `np`.
+        """Replaces `numpy` at the start of a string with `np`.
 
         Args:
             operation (str): The operation as a string.
@@ -88,8 +87,7 @@ class MathExpressionTransformer(BaseTransformer):
         return operation
 
     def transform(self, X: pd.DataFrame) -> pd.DataFrame:
-        """
-        Applies the operation to the column and the value.
+        """Applies the operation to the column and the value.
 
         Args:
             X (pandas.DataFrame): DataFrame containing the columns to apply the operation on.
